@@ -1,6 +1,7 @@
-from models.graph import Graph
-from models.point import Point
-from models.triangle import Triangle
+from ..models.graph import Graph
+from ..models.point import Point
+from ..models.triangle import Triangle
+
 
 class Kirkpatrick:
     def __init__(self, g: Graph):
@@ -8,4 +9,3 @@ class Kirkpatrick:
 
     def locate_point(self, dot: Point):
         pass
-
