@@ -5,7 +5,7 @@ class Line2D:
     """A 2D line represented by the equation Ax + By + C = 0."""
 
     def __init__(self, p1: Point, p2: Point):
-        """Constuct line by two points."""
+        """Construct line by two points."""
         self.p1 = p1
         self.p2 = p2
 
